PALM-meteo: palmmeteo/logging.py File Reference

PALM-meteo

Classes | Namespaces | Functions | Variables
logging.py File Reference

## Classes
class | palmmeteo.logging.LoggingLevel

## Namespaces
namespace | palmmeteo
namespace | palmmeteo.logging

## Functions
def | palmmeteo.logging.die (s, *args, **kwargs)
def | palmmeteo.logging.warn (s, *args, **kwargs)
def | palmmeteo.logging.configure_log (verbosity, log_datetime=False)

## Variables
string | palmmeteo.logging.dtf = '%Y-%m-%d %H:%M:%S '
| palmmeteo.logging.log_output = sys.stdout.write
| palmmeteo.logging.error_output = sys.stderr.write
| palmmeteo.logging.log = LoggingLevel(True)
| palmmeteo.logging.verbose = LoggingLevel(False)